serialize

Function serialize 

pub fn serialize(t: &Value, opts: &Options) -> Result<String, SerError>
Serialize a value graph with the given options.

This is the raw entry point. Returns the Lua source, or an error when fatal is set and a non-serializable value is reached.

Errors

Returns SerError when opts.fatal is set and a value cannot be serialized as data.