pub fn load(data: &str, opts: &LoadOptions) -> Result<Value, LoadError>
Deserialize a serpent fragment.
Accepts either a bare expression or a do ... end block. Returns Ok(value) on success. Returns a LoadError on a parse error, or in safe mode when the input tries to call a function.
do ... end
Ok(value)
LoadError
Returns LoadError when parsing fails or when a call is rejected in safe mode.